# PAN from GSTIN

## Description

This is a Python library to retrieve PAN (India) from input GSTIN 

## Author

Rashmi Rao

## Version History
*0.3 Updated setup.py
*0.2 Added executing program steps
* 0.1 Initial Release

### Installing

* pip install gstin==0.3

### Executing program

* from gstin import fn_gstin
* fn_gstin()
* fn_gstin(your GSTIN in quotes) 
```
code blocks for commands
```
## License

MIT - see the LICENSE.md file for details

